==> weoveri_flutter_widgets-0.0.5.tar.gz: README.md <==
# We Over I - Widget Library


## Overview

The "We Over I Flutter Widgets" package is a comprehensive library of everyday-use widgets for Flutter users. We've gathered all the widgets we've developed into one convenient library, making them easily accessible and beneficial to everyone.


## Table of Content
- [Widgets](#widgets)
- [Installation](#installation)
- [Usage](#usage)
- [Additional information](#additional-information)


## Widgets
Here are the list of widgets in the package. You can visit the link below to find out all of the variations of those widgets.
- [Buttons](https://pub.dev/documentation/weoveri_flutter_widgets/latest/buttons/buttons-library.html)
- [Switches](https://pub.dev/documentation/weoveri_flutter_widgets/latest/switches/switches-library.html)
- [Radio/Checkmarks](https://pub.dev/documentation/weoveri_flutter_widgets/latest/radio_and_checkbox/radio_and_checkbox_library.html)


## Installation

```yaml
# add this line to your dependencies
weoveri_flutter_widgets: ^0.0.5
```

```dart
import 'package:weoveri_flutter_widgets/woi_widgets.dart';
```

## Usage

As simple as using a Flutter's TextButton widget for example in terms of `WOITextButton` here is the example below.

```dart
WOITextButton(
    text: 'Confirm',
)
```

Furture details on the all supported fields and thier use please vist tht [API reference](https://pub.dev/documentation/weoveri_flutter_widgets/latest/) of the documentations.

## Contact
Incase of any issues or assistance please reach out to:
- [We Over I Engineering Team](mailto:tech@we-over-i.com)
- [Muhammad Saad](mailto:saad@we-over-i.com)

## Contributors
- [Saad Javaid Alvi](https://github.com/saadjavaidalvi)
- [Mahnoor Rizwan](mailto:mahnoor@we-over-i.com)

## Licence
This project is licensed under the MIT license, Copyright (c) 2023 We Over I. For more information see
[LICENSE.md](LICENSE)

==> weoveri_flutter_widgets-0.0.6.tar.gz: README.md <==
# We Over I - Widget Library


## Overview

The "We Over I Flutter Widgets" package is a comprehensive library of everyday-use widgets for Flutter users. We've gathered all the widgets we've developed into one convenient library, making them easily accessible and beneficial to everyone.


## Table of Content
- [Widgets](#widgets)
- [Installation](#installation)
- [Usage](#usage)
- [Additional information](#additional-information)


## Widgets
Here are the list of widgets in the package. You can visit the link below to find out all of the variations of those widgets.
- [Buttons](https://pub.dev/documentation/weoveri_flutter_widgets/latest/buttons/buttons-library.html)
- [Switches](https://pub.dev/documentation/weoveri_flutter_widgets/latest/switches/switches-library.html)
- [Radio/Checkmarks](https://pub.dev/documentation/weoveri_flutter_widgets/latest/radio_and_checkbox/radio_and_checkbox-library.html)


## Installation

```yaml
# add this line to your dependencies
weoveri_flutter_widgets: ^0.0.6
```

```dart
import 'package:weoveri_flutter_widgets/woi_widgets.dart';
```

## Usage

As simple as using a Flutter's TextButton widget for example in terms of `WOITextButton` here is the example below.

```dart
WOITextButton(
    text: 'Confirm',
)
```

Furture details on the all supported fields and thier use please vist tht [API reference](https://pub.dev/documentation/weoveri_flutter_widgets/latest/) of the documentations.

## Contact
Incase of any issues or assistance please reach out to:
- [We Over I Engineering Team](mailto:tech@we-over-i.com)
- [Muhammad Saad](mailto:saad@we-over-i.com)

## Contributors
- [Saad Javaid Alvi](https://github.com/saadjavaidalvi)
- [Mahnoor Rizwan](mailto:mahnoor@we-over-i.com)

## Licence
This project is licensed under the MIT license, Copyright (c) 2023 We Over I. For more information see
[LICENSE.md](LICENSE)
